resource_groups = {
    "ovh_vrack_publiccloud_attachment": 0,
    "ovh_publiccloud_private_network": 1,
    "ovh_publiccloud_private_network_subnet": 1,
    "ovh_publiccloud_user": 1,
    "ultradns_dirpool": 2,
    "ultradns_probe_http": 2,
    "ultradns_probe_ping": 2,
    "ultradns_record": 2,
    "ultradns_tcpool": 2,
    "template_dir": 3,
    "azurerm_resource_group": 4,
    "azurerm_app_service": 5,
    "azurerm_app_service_plan": 5,
    "azurerm_role_assignment": 6,
    "azurerm_role_definition": 6,
    "azurerm_automation_account": 7,
    "azurerm_automation_credential": 7,
    "azurerm_automation_runbook": 7,
    "azurerm_automation_schedule": 7,
    "azurerm_application_insights": 8,
    "azurerm_cdn_profile": 9,
    "azurerm_cdn_endpoint": 9,
    "azurerm_availability_set": 10,
    "azurerm_managed_disk": 10,
    "azurerm_snapshot": 10,
    "azurerm_image": 10,
    "azurerm_virtual_machine": 10,
    "azurerm_virtual_machine_extension": 10,
    "azurerm_virtual_machine_scale_set": 10,
    "azurerm_container_group": 11,
    "azurerm_container_registry": 11,
    "azurerm_container_service": 11,
    "azurerm_cosmosdb_account": 12,
    "azurerm_mysql_configuration": 13,
    "azurerm_mysql_database": 13,
    "azurerm_mysql_firewall_rule": 13,
    "azurerm_mysql_server": 13,
    "azurerm_postgresql_configuration": 13,
    "azurerm_postgresql_database": 13,
    "azurerm_postgresql_firewall_rule": 13,
    "azurerm_postgresql_server": 13,
    "azurerm_sql_database": 13,
    "azurerm_sql_elasticpool": 13,
    "azurerm_sql_firewall_rule": 13,
    "azurerm_sql_server": 13,
    "azurerm_dns_a_record": 14,
    "azurerm_dns_aaaa_record": 14,
    "azurerm_dns_cname_record": 14,
    "azurerm_dns_mx_record": 14,
    "azurerm_dns_ns_record": 14,
    "azurerm_dns_ptr_record": 14,
    "azurerm_dns_srv_record": 14,
    "azurerm_dns_txt_record": 14,
    "azurerm_dns_zone": 14,
    "azurerm_key_vault": 15,
    "azurerm_key_vault_certificate": 15,
    "azurerm_key_vault_key": 15,
    "azurerm_key_vault_secret": 15,
    "azurerm_lb": 16,
    "azurerm_lb_backend_address_pool": 16,
    "azurerm_lb_rule": 16,
    "azurerm_lb_nat_rule": 16,
    "azurerm_lb_nat_pool": 16,
    "azurerm_lb_probe": 16,
    "azurerm_eventgrid_topic": 17,
    "azurerm_eventhub": 17,
    "azurerm_eventhub_authorization_rule": 17,
    "azurerm_eventhub_consumer_group": 17,
    "azurerm_eventhub_namespace": 17,
    "azurerm_servicebus_namespace": 17,
    "azurerm_servicebus_queue": 17,
    "azurerm_servicebus_subscription": 17,
    "azurerm_servicebus_topic": 17,
    "azurerm_application_gateway": 18,
    "azurerm_express_route_circuit": 18,
    "azurerm_local_network_gateway": 18,
    "azurerm_network_interface": 18,
    "azurerm_network_security_group": 18,
    "azurerm_network_security_rule": 18,
    "azurerm_public_ip": 18,
    "azurerm_route": 18,
    "azurerm_route_table": 18,
    "azurerm_subnet": 18,
    "azurerm_traffic_manager_endpoint": 18,
    "azurerm_traffic_manager_profile": 18,
    "azurerm_virtual_network": 18,
    "azurerm_virtual_network_peering": 18,
    "azurerm_log_analytics_workspace": 19,
    "azurerm_redis_cache": 20,
    "azurerm_search_service": 21,
    "azurerm_storage_account": 22,
    "azurerm_storage_container": 22,
    "azurerm_storage_blob": 22,
    "azurerm_storage_queue": 22,
    "azurerm_storage_share": 22,
    "azurerm_storage_table": 22,
    "azurerm_template_deployment": 23,
    "cloudstack_affinity_group": 24,
    "cloudstack_disk": 24,
    "cloudstack_egress_firewall": 24,
    "cloudstack_firewall": 24,
    "cloudstack_instance": 24,
    "cloudstack_ipaddress": 24,
    "cloudstack_loadbalancer_rule": 24,
    "cloudstack_network": 24,
    "cloudstack_network_acl": 24,
    "cloudstack_network_acl_rule": 24,
    "cloudstack_nic": 24,
    "cloudstack_port_forward": 24,
    "cloudstack_private_gateway": 24,
    "cloudstack_secondary_ipaddress": 24,
    "cloudstack_security_group": 24,
    "cloudstack_security_group_rule": 24,
    "cloudstack_ssh_keypair": 24,
    "cloudstack_static_nat": 24,
    "cloudstack_static_route": 24,
    "cloudstack_template": 24,
    "cloudstack_vpc": 24,
    "cloudstack_vpn_gateway": 24,
    "cloudstack_vpn_customer_gateway": 24,
    "cloudstack_vpn_connection": 24,
    "circonus_check": 25,
    "circonus_contact_group": 25,
    "circonus_graph": 25,
    "circonus_metric": 25,
    "circonus_metric_cluster": 25,
    "circonus_rule_set": 25,
    "oneandone_firewall_policy": 26,
    "oneandone_loadbalancer": 26,
    "oneandone_monitoring_policy": 26,
    "oneandone_private_network": 26,
    "oneandone_public_ip": 26,
    "oneandone_server": 26,
    "oneandone_shared_storage": 26,
    "oneandone_vpn": 26,
    "docker_container": 27,
    "docker_image": 27,
    "docker_network": 27,
    "docker_volume": 27,
    "cobbler_distro": 28,
    "cobbler_kickstart_file": 28,
    "cobbler_profile": 28,
    "cobbler_snippet": 28,
    "cobbler_system": 28,
    "grafana_alert_notification": 29,
    "grafana_dashboard": 29,
    "grafana_data_source": 29,
    "opc_compute_acl": 30,
    "opc_compute_image_list": 30,
    "opc_compute_image_list_entry": 30,
    "opc_compute_instance": 30,
    "opc_compute_ip_address_association": 30,
    "opc_compute_ip_address_prefix_set": 30,
    "opc_compute_ip_address_reservation": 30,
    "opc_compute_ip_association": 30,
    "opc_compute_ip_network": 30,
    "opc_compute_ip_network_exchange": 30,
    "opc_compute_ip_reservation": 30,
    "opc_compute_route": 30,
    "opc_compute_sec_rule": 30,
    "opc_compute_security_application": 30,
    "opc_compute_security_association": 30,
    "opc_compute_security_ip_list": 30,
    "opc_compute_security_list": 30,
    "opc_compute_security_protocol": 30,
    "opc_compute_security_rule": 30,
    "opc_compute_ssh_key": 30,
    "opc_compute_storage_volume": 30,
    "opc_compute_storage_volume_snapshot": 30,
    "opc_compute_vnic_set": 30,
    "ns1_zone": 31,
    "ns1_record": 31,
    "ns1_monitoringjob": 31,
    "ns1_notifylist": 31,
    "ns1_datasource": 31,
    "ns1_datafeed": 31,
    "ns1_apikey": 31,
    "ns1_team": 31,
    "ns1_user": 31,
    "service_v1": 32,
    "mailgun_domain": 33,
    "tls_private_key": 34,
    "tls_self_signed_cert": 34,
    "tls_locally_signed_cert": 34,
    "tls_cert_request": 34,
    "vsphere_license": 35,
    "vsphere_datacenter": 36,
    "vsphere_folder": 36,
    "vsphere_tag": 36,
    "vsphere_tag_category": 36,
    "vsphere_distributed_port_group": 37,
    "vsphere_distributed_virtual_switch": 37,
    "vsphere_host_port_group": 37,
    "vsphere_host_virtual_switch": 37,
    "vsphere_file": 38,
    "vsphere_nas_datastore": 38,
    "vsphere_vmfs_datastore": 38,
    "vsphere_virtual_disk": 39,
    "vsphere_virtual_machine": 39,
    "vsphere_virtual_machine_snapshot": 39,
    "packet_device": 40,
    "packet_project": 40,
    "packet_ssh_key": 40,
    "packet_volume": 40,
    "packet_volume_attachment": 40,
    "dme_record": 41,
    "clc_server": 42,
    "clc_group": 42,
    "clc_public_ip": 42,
    "clc_load_balancer": 42,
    "clc_load_balancer_pool": 42,
    "nomad_job": 43,
    "triton_key": 44,
    "triton_firewall_rule": 44,
    "triton_vlan": 44,
    "triton_fabric": 44,
    "triton_machine": 44,
    "cloudscale_server": 45,
    "cloudscale_floating_ip": 45,
    "random_id": 46,
    "random_pet": 46,
    "random_shuffle": 46,
    "random_string": 46,
    "opsgenie_team": 47,
    "opsgenie_user": 47,
    "gitlab_deploy_key": 48,
    "gitlab_group": 48,
    "gitlab_label": 48,
    "gitlab_project_hook": 48,
    "gitlab_project": 48,
    "gitlab_user": 48,
    "rabbitmq_binding": 49,
    "rabbitmq_exchange": 49,
    "rabbitmq_permissions": 49,
    "rabbitmq_policy": 49,
    "rabbitmq_queue": 49,
    "rabbitmq_user": 49,
    "rabbitmq_vhost": 49,
    "logicmonitor_collectorgroup": 50,
    "logicmonitor_device": 50,
    "logicmonitor_devicegroup": 50,
    "statuscake_test": 51,
    "openstack_blockstorage_volume_v1": 52,
    "openstack_blockstorage_volume_v2": 52,
    "openstack_blockstorage_volume_attach_v2": 52,
    "openstack_compute_flavor_v2": 53,
    "openstack_compute_floatingip_v2": 53,
    "openstack_compute_floatingip_associate_v2": 53,
    "openstack_compute_instance_v2": 53,
    "openstack_compute_keypair_v2": 53,
    "openstack_compute_secgroup_v2": 53,
    "openstack_compute_servergroup_v2": 53,
    "openstack_compute_volume_attach_v2": 53,
    "openstack_dns_recordset_v2": 54,
    "openstack_dns_zone_v2": 54,
    "openstack_identity_project_v3": 55,
    "openstack_identity_user_v3": 55,
    "openstack_images_image_v2": 56,
    "openstack_networking_floatingip_v2": 57,
    "openstack_networking_network_v2": 57,
    "openstack_networking_port_v2": 57,
    "openstack_networking_router_interface_v2": 57,
    "openstack_networking_router_route_v2": 57,
    "openstack_networking_router_v2": 57,
    "openstack_networking_subnet_v2": 57,
    "openstack_networking_secgroup_v2": 57,
    "openstack_networking_secgroup_rule_v2": 57,
    "openstack_lb_member_v1": 58,
    "openstack_lb_monitor_v1": 58,
    "openstack_lb_pool_v1": 58,
    "openstack_lb_vip_v1": 58,
    "openstack_lb_loadbalancer_v2": 58,
    "openstack_lb_listener_v2": 58,
    "openstack_lb_pool_v2": 58,
    "openstack_lb_member_v2": 58,
    "openstack_lb_monitor_v2": 58,
    "openstack_fw_firewall_v1": 59,
    "openstack_fw_policy_v1": 59,
    "openstack_fw_rule_v1": 59,
    "openstack_objectstorage_container_v1": 60,
    "kubernetes_config_map": 61,
    "kubernetes_horizontal_pod_autoscaler": 61,
    "kubernetes_limit_range": 61,
    "kubernetes_namespace": 61,
    "kubernetes_persistent_volume": 61,
    "kubernetes_persistent_volume_claim": 61,
    "kubernetes_pod": 61,
    "kubernetes_replication_controller": 61,
    "kubernetes_resource_quota": 61,
    "kubernetes_secret": 61,
    "kubernetes_service": 61,
    "kubernetes_service_account": 61,
    "kubernetes_storage_class": 61,
    "aws_group": 62,
    "newrelic_alert_channel": 63,
    "newrelic_alert_condition": 63,
    "newrelic_alert_policy": 63,
    "newrelic_alert_policy_channel": 63,
    "newrelic_nrql_alert_condition": 63,
    "google_bigquery_dataset": 65,
    "google_bigquery_table": 65,
    "google_bigtable_instance": 66,
    "google_bigtable_table": 66,
    "google_folder": 67,
    "google_folder_iam_policy": 67,
    "google_organization_policy": 67,
    "google_project": 67,
    "google_project_iam_binding": 67,
    "google_project_iam_member": 67,
    "google_project_iam_policy": 67,
    "google_project_services": 67,
    "google_service_account": 67,
    "google_compute_address": 68,
    "google_compute_autoscaler": 68,
    "google_compute_backend_bucket": 68,
    "google_compute_backend_service": 68,
    "google_compute_disk": 68,
    "google_compute_firewall": 68,
    "google_compute_forwarding_rule": 68,
    "google_compute_global_address": 68,
    "google_compute_global_forwarding_rule": 68,
    "google_compute_health_check": 68,
    "google_compute_http_health_check": 68,
    "google_compute_https_health_check": 68,
    "google_compute_image": 68,
    "google_compute_instance": 68,
    "google_compute_instance_group": 68,
    "google_compute_instance_group_manager": 68,
    "google_compute_instance_template": 68,
    "google_compute_network_peering": 68,
    "google_compute_network": 68,
    "google_compute_project_metadata": 68,
    "google_compute_project_metadata_item": 68,
    "google_compute_region_autoscaler": 68,
    "google_compute_region_backend_service": 68,
    "google_compute_region_instance_group_manager": 68,
    "google_compute_route": 68,
    "google_compute_router": 68,
    "google_compute_router_interface": 68,
    "google_compute_router_peer": 68,
    "google_compute_shared_vpc_host_project": 68,
    "google_compute_shared_vpc_service_project": 68,
    "google_compute_snapshot": 68,
    "google_compute_ssl_certificate": 68,
    "google_compute_subnetwork": 68,
    "google_compute_target_http_proxy": 68,
    "google_compute_target_https_proxy": 68,
    "google_compute_target_ssl_proxy": 68,
    "google_compute_target_tcp_proxy": 68,
    "google_compute_target_pool": 68,
    "google_compute_url_map": 68,
    "google_compute_vpn_gateway": 68,
    "google_compute_vpn_tunnel": 68,
    "google_container_cluster": 69,
    "google_container_node_pool": 69,
    "google_dns_managed_zone": 70,
    "google_dns_record_set": 70,
    "google_pubsub_topic": 71,
    "google_pubsub_subscription": 71,
    "google_runtimeconfig_config": 72,
    "google_runtimeconfig_variable": 72,
    "google_sourcerepo_repository": 73,
    "google_spanner_instance": 74,
    "google_spanner_database": 74,
    "google_sql_database": 75,
    "google_sql_database_instance": 75,
    "google_sql_user": 75,
    "google_logging_billing_account_sink": 76,
    "google_logging_folder_sink": 76,
    "google_logging_project_sink": 76,
    "google_storage_bucket": 77,
    "google_storage_bucket_acl": 77,
    "google_storage_bucket_object": 77,
    "google_storage_object_acl": 77,
    "postgresql_database": 78,
    "postgresql_extension": 78,
    "postgresql_role": 78,
    "postgresql_schema": 78,
    "heroku_addon": 79,
    "heroku_addon_attachment": 79,
    "heroku_app": 79,
    "heroku_app_feature": 79,
    "heroku_cert": 79,
    "heroku_domain": 79,
    "heroku_drain": 79,
    "heroku_pipeline": 79,
    "heroku_pipeline_coupling": 79,
    "heroku_space": 79,
    "influxdb_database": 80,
    "influxdb_user": 80,
    "influxdb_continuous_query": 80,
    "aws_api_gateway_account": 81,
    "aws_api_gateway_api_key": 81,
    "aws_api_gateway_authorizer": 81,
    "aws_api_gateway_base_path_mapping": 81,
    "aws_api_gateway_client_certificate": 81,
    "aws_api_gateway_deployment": 81,
    "aws_api_gateway_domain_name": 81,
    "aws_api_gateway_gateway_response": 81,
    "aws_api_gateway_integration": 81,
    "aws_api_gateway_integration_response": 81,
    "aws_api_gateway_method": 81,
    "aws_api_gateway_method_response": 81,
    "aws_api_gateway_method_settings": 81,
    "aws_api_gateway_model": 81,
    "aws_api_gateway_resource": 81,
    "aws_api_gateway_rest_api": 81,
    "aws_api_gateway_stage": 81,
    "aws_api_gateway_usage_plan": 81,
    "aws_api_gateway_usage_plan_key": 81,
    "aws_appautoscaling_policy": 82,
    "aws_appautoscaling_target": 82,
    "aws_batch_compute_environment": 83,
    "aws_batch_job_definition": 83,
    "aws_batch_job_queue": 83,
    "aws_cloudformation_stack": 84,
    "aws_cloudfront_distribution": 85,
    "aws_cloudfront_origin_access_identity": 85,
    "aws_cloudtrail": 86,
    "aws_cloudwatch_dashboard": 87,
    "aws_cloudwatch_event_rule": 87,
    "aws_cloudwatch_event_target": 87,
    "aws_cloudwatch_log_destination": 87,
    "aws_cloudwatch_log_destination_policy": 87,
    "aws_cloudwatch_log_group": 87,
    "aws_cloudwatch_log_metric_filter": 87,
    "aws_cloudwatch_log_stream": 87,
    "aws_cloudwatch_log_subscription_filter": 87,
    "aws_cloudwatch_metric_alarm": 87,
    "aws_codebuild_project": 88,
    "aws_codecommit_repository": 89,
    "aws_codecommit_trigger": 89,
    "aws_codedeploy_app": 90,
    "aws_codedeploy_deployment_config": 90,
    "aws_codedeploy_deployment_group": 90,
    "aws_codepipeline": 91,
    "aws_cognito_identity_pool": 92,
    "aws_cognito_identity_pool_roles_attachment": 92,
    "aws_config_config_rule": 93,
    "aws_config_configuration_recorder": 93,
    "aws_config_configuration_recorder_status": 93,
    "aws_config_delivery_channel": 93,
    "aws_dms_certificate": 94,
    "aws_dms_endpoint": 94,
    "aws_dms_replication_instance": 94,
    "aws_dms_replication_subnet_group": 94,
    "aws_dms_replication_task": 94,
    "aws_devicefarm_project": 95,
    "aws_directory_service_directory": 96,
    "aws_dynamodb_table": 97,
    "aws_alb": 98,
    "aws_alb_listener": 98,
    "aws_alb_listener_rule": 98,
    "aws_alb_target_group": 98,
    "aws_alb_target_group_attachment": 98,
    "aws_ami": 98,
    "aws_ami_copy": 98,
    "aws_ami_from_instance": 98,
    "aws_ami_launch_permission": 98,
    "aws_app_cookie_stickiness_policy": 98,
    "aws_autoscaling_attachment": 98,
    "aws_autoscaling_group": 98,
    "aws_autoscaling_lifecycle_hook": 98,
    "aws_autoscaling_notification": 98,
    "aws_autoscaling_policy": 98,
    "aws_autoscaling_schedule": 98,
    "aws_snapshot_create_volume_permission": 98,
    "aws_ebs_snapshot": 98,
    "aws_ebs_volume": 98,
    "aws_eip": 98,
    "aws_eip_association": 98,
    "aws_elb": 98,
    "aws_elb_attachment": 98,
    "aws_instance": 98,
    "aws_key_pair": 98,
    "aws_launch_configuration": 98,
    "aws_lb_cookie_stickiness_policy": 98,
    "aws_lb_ssl_negotiation_policy": 98,
    "aws_load_balancer_backend_server_policy": 98,
    "aws_load_balancer_listener_policy": 98,
    "aws_load_balancer_policy": 98,
    "aws_placement_group": 98,
    "aws_proxy_protocol_policy": 98,
    "aws_spot_datafeed_subscription": 98,
    "aws_spot_fleet_request": 98,
    "aws_spot_instance_request": 98,
    "aws_volume_attachment": 98,
    "aws_lb": 99,
    "aws_lb_listener": 99,
    "aws_lb_listener_rule": 99,
    "aws_lb_target_group": 99,
    "aws_lb_target_group_attachment": 99,
    "aws_ecr_lifecycle_policy": 100,
    "aws_ecr_repository": 100,
    "aws_ecr_repository_policy": 100,
    "aws_ecs_cluster": 100,
    "aws_ecs_service": 100,
    "aws_ecs_task_definition": 100,
    "aws_efs_file_system": 101,
    "aws_efs_mount_target": 101,
    "aws_elasticache_cluster": 102,
    "aws_elasticache_parameter_group": 102,
    "aws_elasticache_replication_group": 102,
    "aws_elasticache_security_group": 102,
    "aws_elasticache_subnet_group": 102,
    "aws_elastic_beanstalk_application": 103,
    "aws_elastic_beanstalk_application_version": 103,
    "aws_elastic_beanstalk_configuration_template": 103,
    "aws_elastic_beanstalk_environment": 103,
    "aws_emr_cluster": 104,
    "aws_emr_instance_group": 104,
    "aws_emr_security_configuration": 104,
    "aws_elasticsearch_domain": 105,
    "aws_elasticsearch_domain_policy": 105,
    "aws_elastictranscoder_pipeline": 106,
    "aws_elastictranscoder_preset": 106,
    "aws_glacier_vault": 107,
    "aws_iam_access_key": 108,
    "aws_iam_account_alias": 108,
    "aws_iam_account_password_policy": 108,
    "aws_iam_group": 108,
    "aws_iam_group_membership": 108,
    "aws_iam_group_policy": 108,
    "aws_iam_group_policy_attachment": 108,
    "aws_iam_instance_profile": 108,
    "aws_iam_openid_connect_provider": 108,
    "aws_iam_policy": 108,
    "aws_iam_policy_attachment": 108,
    "aws_iam_role": 108,
    "aws_iam_role_policy": 108,
    "aws_iam_role_policy_attachment": 108,
    "aws_iam_saml_provider": 108,
    "aws_iam_server_certificate": 108,
    "aws_iam_user": 108,
    "aws_iam_user_login_profile": 108,
    "aws_iam_user_policy": 108,
    "aws_iam_user_policy_attachment": 108,
    "aws_iam_user_ssh_key": 108,
    "aws_iot_certificate": 109,
    "aws_iot_policy": 109,
    "aws_inspector_assessment_target": 110,
    "aws_inspector_assessment_template": 110,
    "aws_inspector_resource_group": 110,
    "aws_kinesis_stream": 111,
    "aws_kinesis_firehose_delivery_stream": 112,
    "aws_kms_alias": 113,
    "aws_kms_key": 113,
    "aws_lambda_alias": 114,
    "aws_lambda_event_source_mapping": 114,
    "aws_lambda_function": 114,
    "aws_lambda_permission": 114,
    "aws_lightsail_domain": 115,
    "aws_lightsail_instance": 115,
    "aws_lightsail_key_pair": 115,
    "aws_lightsail_static_ip": 115,
    "aws_lightsail_static_ip_attachment": 115,
    "aws_opsworks_application": 116,
    "aws_opsworks_custom_layer": 116,
    "aws_opsworks_ganglia_layer": 116,
    "aws_opsworks_haproxy_layer": 116,
    "aws_opsworks_instance": 116,
    "aws_opsworks_java_app_layer": 116,
    "aws_opsworks_memcached_layer": 116,
    "aws_opsworks_mysql_layer": 116,
    "aws_opsworks_nodejs_app_layer": 116,
    "aws_opsworks_permission": 116,
    "aws_opsworks_php_app_layer": 116,
    "aws_opsworks_rails_app_layer": 116,
    "aws_opsworks_rds_db_instance": 116,
    "aws_opsworks_stack": 116,
    "aws_opsworks_static_web_layer": 116,
    "aws_opsworks_user_profile": 116,
    "aws_db_event_subscription": 117,
    "aws_db_instance": 117,
    "aws_db_option_group": 117,
    "aws_db_parameter_group": 117,
    "aws_db_security_group": 117,
    "aws_db_snapshot": 117,
    "aws_db_subnet_group": 117,
    "aws_rds_cluster": 117,
    "aws_rds_cluster_instance": 117,
    "aws_rds_cluster_parameter_group": 117,
    "aws_redshift_cluster": 118,
    "aws_redshift_parameter_group": 118,
    "aws_redshift_security_group": 118,
    "aws_redshift_subnet_group": 118,
    "aws_waf_byte_match_set": 119,
    "aws_waf_ipset": 119,
    "aws_waf_rule": 119,
    "aws_waf_rate_based_rule": 119,
    "aws_waf_size_constraint_set": 119,
    "aws_waf_sql_injection_match_set": 119,
    "aws_waf_web_acl": 119,
    "aws_waf_xss_match_set": 119,
    "aws_wafregional_byte_match_set": 120,
    "aws_wafregional_ipset": 120,
    "aws_route53_delegation_set": 121,
    "aws_route53_health_check": 121,
    "aws_route53_record": 121,
    "aws_route53_zone": 121,
    "aws_route53_zone_association": 121,
    "aws_s3_bucket": 122,
    "aws_s3_bucket_notification": 122,
    "aws_s3_bucket_object": 122,
    "aws_s3_bucket_policy": 122,
    "aws_ses_active_receipt_rule_set": 123,
    "aws_ses_domain_identity": 123,
    "aws_ses_domain_dkim": 123,
    "aws_ses_receipt_filter": 123,
    "aws_ses_receipt_rule": 123,
    "aws_ses_receipt_rule_set": 123,
    "aws_ses_configuration_set": 123,
    "aws_ses_event_destination": 123,
    "aws_servicecatalog_portfolio": 124,
    "aws_sfn_activity": 125,
    "aws_sfn_state_machine": 125,
    "aws_simpledb_domain": 126,
    "aws_sns_topic": 127,
    "aws_sns_topic_policy": 127,
    "aws_sns_topic_subscription": 127,
    "aws_ssm_activation": 128,
    "aws_ssm_association": 128,
    "aws_ssm_document": 128,
    "aws_ssm_maintenance_window": 128,
    "aws_ssm_maintenance_window_target": 128,
    "aws_ssm_maintenance_window_task": 128,
    "aws_ssm_patch_baseline": 128,
    "aws_ssm_patch_group": 128,
    "aws_ssm_parameter": 128,
    "aws_sqs_queue": 129,
    "aws_sqs_queue_policy": 129,
    "aws_customer_gateway": 130,
    "aws_default_network_acl": 130,
    "aws_default_route_table": 130,
    "aws_default_security_group": 130,
    "aws_default_subnet": 130,
    "aws_default_vpc": 130,
    "aws_default_vpc_dhcp_options": 130,
    "aws_egress_only_internet_gateway": 130,
    "aws_flow_log": 130,
    "aws_internet_gateway": 130,
    "aws_main_route_table_association": 130,
    "aws_nat_gateway": 130,
    "aws_network_acl": 130,
    "aws_network_acl_rule": 130,
    "aws_network_interface": 130,
    "aws_network_interface_attachment": 130,
    "aws_route": 130,
    "aws_route_table": 130,
    "aws_route_table_association": 130,
    "aws_security_group": 130,
    "aws_network_interface_sg_attachment": 130,
    "aws_security_group_rule": 130,
    "aws_subnet": 130,
    "aws_vpc": 130,
    "aws_vpc_dhcp_options": 130,
    "aws_vpc_dhcp_options_association": 130,
    "aws_vpc_endpoint": 130,
    "aws_vpc_endpoint_route_table_association": 130,
    "aws_vpc_peering_connection": 130,
    "aws_vpc_peering_connection_accepter": 130,
    "aws_vpn_connection": 130,
    "aws_vpn_connection_route": 130,
    "aws_vpn_gateway": 130,
    "aws_vpn_gateway_attachment": 130,
    "aws_vpn_gateway_route_propagation": 130,
    "azure_affinity_group": 131,
    "azure_data_disk": 131,
    "azure_dns_server": 131,
    "azure_hosted_service": 131,
    "azure_instance": 131,
    "azure_local_network_connection": 131,
    "azure_security_group": 131,
    "azure_security_group_rule": 131,
    "azure_sql_database_server": 131,
    "azure_sql_database_server_firewall_rule": 131,
    "azure_sql_database_service": 131,
    "azure_storage_blob": 131,
    "azure_storage_container": 131,
    "azure_storage_queue": 131,
    "azure_storage_service": 131,
    "azure_virtual_network": 131,
    "alicloud_disk": 132,
    "alicloud_disk_attachment": 132,
    "alicloud_instance": 132,
    "alicloud_eip": 132,
    "alicloud_eip_association": 132,
    "alicloud_slb": 133,
    "alicloud_slb_attachment": 133,
    "alicloud_vpc": 134,
    "alicloud_vswitch": 134,
    "alicloud_route_entry": 134,
    "alicloud_security_group": 134,
    "alicloud_security_group_rule": 134,
    "alicloud_nat_gateway": 134,
    "alicloud_rds": 135,
    "alicloud_ess_scaling_group": 136,
    "alicloud_ess_scaling_configuration": 136,
    "alicloud_ess_scaling_rule": 136,
    "alicloud_ess_schedule": 136,
    "cloudflare_record": 137,
    "scaleway_ip": 138,
    "scaleway_server": 138,
    "scaleway_security_group": 138,
    "scaleway_security_group_rule": 138,
    "scaleway_volume": 138,
    "scaleway_volume_attachment": 138,
    "logentries_log": 139,
    "logentries_logset": 139,
    "file": 140,
    "vcd_dnat": 141,
    "vcd_firewall_rules": 141,
    "vcd_network": 141,
    "vcd_snat": 141,
    "vcd_edgegateway_vpn": 141,
    "vcd_vapp": 141,
    "vcd_vapp_vm": 141,
    "chef_data_bag": 142,
    "chef_data_bag_item": 142,
    "chef_environment": 142,
    "chef_node": 142,
    "chef_role": 142,
    "pagerduty_addon": 143,
    "pagerduty_escalation_policy": 143,
    "pagerduty_maintenance_window": 143,
    "pagerduty_schedule": 143,
    "pagerduty_service": 143,
    "pagerduty_service_integration": 143,
    "pagerduty_team": 143,
    "pagerduty_team_membership": 143,
    "pagerduty_user": 143,
    "dns_a_record_set": 144,
    "dns_aaaa_record_set": 144,
    "dns_cname_record": 144,
    "dns_ptr_record": 144,
    "rancher_certificate": 145,
    "rancher_environment": 145,
    "rancher_host": 145,
    "rancher_registration_token": 145,
    "rancher_registry_credential": 145,
    "rancher_registry": 145,
    "rancher_secret": 145,
    "rancher_stack": 145,
    "virtual_guest": 146,
    "ssh_key": 146,
    "bitbucket_default_reviewers": 147,
    "bitbucket_hook": 147,
    "bitbucket_repository": 147,
    "dyn_record": 148,
    "icinga2_checkcommand": 149,
    "icinga2_host": 149,
    "icinga2_hostgroup": 149,
    "icinga2_service": 149,
    "consul_agent_service": 150,
    "consul_catalog_entry": 150,
    "consul_keys": 150,
    "consul_key_prefix": 150,
    "consul_node": 150,
    "consul_prepared_query": 150,
    "consul_service": 150,
    "dnsimple_record": 151,
    "vault_auth_backend": 152,
    "vault_generic_secret": 152,
    "vault_mount": 152,
    "vault_policy": 152,
    "digitalocean_certificate": 153,
    "digitalocean_domain": 153,
    "digitalocean_droplet": 153,
    "digitalocean_firewall": 153,
    "digitalocean_floating_ip": 153,
    "digitalocean_loadbalancer": 153,
    "digitalocean_record": 153,
    "digitalocean_ssh_key": 153,
    "digitalocean_tag": 153,
    "digitalocean_volume": 153,
    "mysql_database": 154,
    "mysql_grant": 154,
    "mysql_user": 154,
    "rundeck_project": 155,
    "rundeck_private_key": 155,
    "rundeck_public_key": 155,
    "rundeck_job": 155,
    "datadog_downtime": 156,
    "datadog_monitor": 156,
    "datadog_timeboard": 156,
    "datadog_user": 156,
    "profitbricks_datacenter": 157,
    "profitbricks_firewall": 157,
    "profitbricks_group": 157,
    "profitbricks_ipblock": 157,
    "profitbricks_ipfailover": 157,
    "profitbricks_lan": 157,
    "profitbricks_loadbalancer": 157,
    "profitbricks_nic": 157,
    "profitbricks_server": 157,
    "profitbricks_share": 157,
    "profitbricks_snapshot": 157,
    "profitbricks_user": 157,
    "profitbricks_volume": 157,
    "powerdns_record": 158,
    "librato_alert": 159,
    "librato_metric": 159,
    "librato_service": 159,
    "librato_space": 159,
    "librato_space_chart": 159,
    "github_branch_protection": 160,
    "github_membership": 160,
    "github_organization_webhook": 160,
    "github_repository": 160,
    "github_repository_collaborator": 160,
    "github_repository_deploy_key": 160,
    "github_repository_webhook": 160,
    "github_team": 160,
    "github_team_membership": 160,
    "github_team_repository": 160,
    "github_issue_label": 160,
    "": 10000,
    "provider": 10000,
    "meta": 10000,
    "var": 10001,
    "output": 10002
}
